import { IgRect } from "igniteui-react-core";
import { IgPoint } from "igniteui-react-core";
import { IgrVerticalAnchoredCategorySeries, IIgrVerticalAnchoredCategorySeriesProps } from "./igr-vertical-anchored-category-series";
import { BarSeries } from "./BarSeries";
/**
 * Represents a IgxDataChartComponent bar series.
*/
export declare class IgrBarSeries extends IgrVerticalAnchoredCategorySeries<IIgrBarSeriesProps> {
    protected createImplementation(): BarSeries;
    /**
                                 * @hidden
                                 */
    get i(): BarSeries;
    constructor(props: IIgrBarSeriesProps);
    /**
     * Gets whether the current series shows a bar shape.
    */
    get isBar(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
    */
    get radiusX(): number;
    set radiusX(v: number);
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
    */
    get radiusY(): number;
    set radiusY(v: number);
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
}
export interface IIgrBarSeriesProps extends IIgrVerticalAnchoredCategorySeriesProps {
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
    */
    radiusX?: number | string;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
    */
    radiusY?: number | string;
}
